/*
FullCalendar React Component v5.0.0-beta.2
Docs: https://fullcalendar.io/docs/react
License: MIT
*/
(function (global, factory) {
    typeof exports === 'object' && typeof module !== 'undefined' ? factory(exports, require('react'), require('react-dom'), require('@fullcalendar/core')) :
    typeof define === 'function' && define.amd ? define(['exports', 'react', 'react-dom', '@fullcalendar/core'], factory) :
    (global = global || self, factory(global.FullCalendarReact = {}, global.React, global.ReactDOM, global.FullCalendar));
}(this, (function (exports, React, ReactDOM, core) { 'use strict';

    /*! *****************************************************************************
    Copyright (c) Microsoft Corporation. All rights reserved.
    Licensed under the Apache License, Version 2.0 (the "License"); you may not use
    this file except in compliance with the License. You may obtain a copy of the
    License at http://www.apache.org/licenses/LICENSE-2.0

    THIS CODE IS PROVIDED ON AN *AS IS* BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
    KIND, EITHER EXPRESS OR IMPLIED, INCLUDING WITHOUT LIMITATION ANY IMPLIED
    WARRANTIES OR CONDITIONS OF TITLE, FITNESS FOR A PARTICULAR PURPOSE,
    MERCHANTABLITY OR NON-INFRINGEMENT.

    See the Apache Version 2.0 License for specific language governing permissions
    and limitations under the License.
    ***************************************************************************** */
    /* global Reflect, Promise */

    var extendStatics = function(d, b) {
        extendStatics = Object.setPrototypeOf ||
            ({ __proto__: [] } instanceof Array && function (d, b) { d.__proto__ = b; }) ||
            function (d, b) { for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p]; };
        return extendStatics(d, b);
    };

    function __extends(d, b) {
        extendStatics(d, b);
        function __() { this.constructor = d; }
        d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
    }

    var __assign = function() {
        __assign = Object.assign || function __assign(t) {
            for (var s, i = 1, n = arguments.length; i < n; i++) {
                s = arguments[i];
                for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p)) t[p] = s[p];
            }
            return t;
        };
        return __assign.apply(this, arguments);
    };

    function diffProps(oldProps, newProps) {
        var updates = {};
        var removals = [];
        var anyChanges = false;
        for (var propName in newProps) {
            if (newProps[propName] !== oldProps[propName]) {
                updates[propName] = newProps[propName];
                anyChanges = true;
            }
        }
        for (var propName in oldProps) {
            if (!(propName in newProps)) {
                removals.push(propName);
                anyChanges = true;
            }
        }
        return { updates: updates, removals: removals, anyChanges: anyChanges };
    }

    var FullCalendar = /** @class */ (function (_super) {
        __extends(FullCalendar, _super);
        function FullCalendar() {
            var _this = _super !== null && _super.apply(this, arguments) || this;
            _this.elRef = React.createRef();
            return _this;
        }
        FullCalendar.prototype.render = function () {
            return (React.createElement("div", { ref: this.elRef }));
        };
        FullCalendar.prototype.componentDidMount = function () {
            this.calendar = new core.Calendar(this.elRef.current, processInitialOptions(this.props));
            this.calendar.render();
        };
        FullCalendar.prototype.componentDidUpdate = function (oldProps) {
            var diff = diffProps(oldProps, this.props);
            if (diff.anyChanges) {
                this.calendar.mutateOptions(diff.updates, diff.removals);
            }
        };
        FullCalendar.prototype.componentWillUnmount = function () {
            this.calendar.destroy();
        };
        FullCalendar.prototype.getApi = function () {
            return this.calendar;
        };
        return FullCalendar;
    }(React.Component));
    /*
    stuff to accommodate react-rendering in *Content settings...
    (when we fullcalendar core supports real-react, this will go away)
    */
    function processInitialOptions(options) {
        var processedOptions = core.mapHash(options, function (optionVal, optionName) {
            if (typeof optionVal === 'function' &&
                optionName.match(/Content$/) // HACKY. only settings like eventContent
            ) {
                return wrapVDomGenerator(optionVal); // will return a result like { react:.. }
            }
            else {
                return optionVal;
            }
        });
        return __assign(__assign({}, processedOptions), { plugins: (processedOptions.plugins || []).concat([
                ReactContentTypePlugin
            ]) });
    }
    function wrapVDomGenerator(vDomGenerator) {
        return function () {
            return { react: vDomGenerator.apply(this, arguments) };
        };
    }
    var ReactContentTypePlugin = core.createPlugin({
        contentTypeHandlers: {
            react: buildVDomHandler
        }
    });
    function buildVDomHandler() {
        var currentEl;
        return function (el, vDomContent) {
            if (currentEl !== el) {
                if (currentEl) {
                    ReactDOM.unmountComponentAtNode(currentEl);
                }
                currentEl = el;
            }
            ReactDOM.render(vDomContent, el);
        };
    }

    exports.default = FullCalendar;

    Object.defineProperty(exports, '__esModule', { value: true });

})));
